@@ -17,6 +17,7 @@
  * along with QCAD.
  */
 
+include("scripts/library.js");
 include("scripts/sprintf.js");
 
 if (exists("scripts/Navigation/DefaultNavigation/DefaultNavigation.js")) {
@@ -217,13 +218,7 @@ ViewportWidget.prototype.init = function(uiFile, graphicsSceneClass) {
         this.graphicsView.setNavigationAction(navigationAction);
     }
 
-    var grid;
-    if (isFunction(this.graphicsView.getRGraphicsView)) {
-        grid = new ROrthoGrid(this.graphicsView.getRGraphicsView());
-    }
-    else {
-        grid = new ROrthoGrid(this.graphicsView);
-    }
+    var grid = new ROrthoGrid(getRGraphicsView(this.graphicsView));
 
     this.graphicsView.setGrid(grid);
 
@@ -344,13 +339,28 @@ EventHandler.prototype.drop = function(event) {
 
     var action;
     if (urls[0].isLocalFile()) {
-        var file = urls[0].toLocalFile();
-        EAction.handleUserMessage(qsTr("Importing file: ") + file);
-        if (new QFileInfo(file).isFile()) {
+        var filePath = urls[0].toLocalFile();
+        var fi = new QFileInfo(filePath);
+        if (fi.suffix().toLowerCase()==="cxf") {
+            //openFiles(urls[0]);
+            //event.acceptProposedAction();
+            //event.ignore();
+            EAction.handleUserWarning(qsTr("Cannot import file into existing drawing:") + " " + filePath);
+            return;
+        }
+
+        EAction.handleUserMessage(qsTr("Importing file:") + " " + filePath);
+        if (fi.isFile()) {
             include("scripts/Block/InsertScriptItem/InsertScriptItem.js");
-            if (InsertScriptItem.isScriptFile(file)) {
+            include("scripts/Draw/Image/Image.js");
+
+            if (InsertScriptItem.isScriptFile(filePath)) {
                 action = RGuiAction.getByScriptFile("scripts/Block/InsertScriptItem/InsertScriptItem.js");
-            } else {
+            }
+            else if (Image.isSupportedBitmapFile(filePath)) {
+                action = RGuiAction.getByScriptFile("scripts/Draw/Image/Image.js");
+            }
+            else {
                 action = RGuiAction.getByScriptFile("scripts/Block/InsertBlockItem/InsertBlockItem.js");
             }
         }
@@ -367,5 +377,6 @@ EventHandler.prototype.drop = function(event) {
 
     action.setData(urls[0]);
     action.slotTrigger();
+    event.acceptProposedAction();
     event.accept();
 };
